==> adx-common-2.5.0.15-sources.jar: com/bxm/adx/common/buy/dsp/DspDaoImpl.java <==
package com.bxm.adx.common.buy.dsp;

import com.bxm.warcar.cache.Fetcher;
import com.bxm.warcar.cache.KeyGenerator;
import com.bxm.warcar.cache.Updater;
import com.bxm.warcar.cache.push.Pushable;
import com.bxm.warcar.integration.pushable.annotation.CachePush;
import com.bxm.warcar.utils.JsonHelper;
import com.bxm.warcar.utils.KeyBuilder;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeansException;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.context.ApplicationListener;
import org.springframework.stereotype.Component;

import java.util.Collection;
import java.util.Map;
import java.util.Objects;

/**
 * For cache pushable
 *
 * <pre>
 *     name = "DSP"
 *     parameters = {}
 *     byte[] = Dsp object to json bytes
 * </pre>
 * @author allen
 * @since 2019-12-18
 */
@CachePush("DSP")
@Component
@Slf4j
public class DspDaoImpl implements DspDao, Pushable, ApplicationContextAware {

    private final Fetcher fetcher;
    private final Updater updater;

    private ApplicationContext applicationContext;

    public DspDaoImpl(Fetcher fetcher, Updater updater) {
        this.fetcher = fetcher;
        this.updater = updater;
    }

    @Override
    public void setApplicationContext(ApplicationContext applicationContext) throws BeansException {
        this.applicationContext = applicationContext;
    }

    @Override
    public Collection<Dsp> getAll() {
        return fetcher.hfetchall(getKeyGenerator(), Dsp.class).values();
    }

    @Override
    public void push(Map<String, Object> parameters, byte[] data) {
        if (log.isDebugEnabled()) {
            log.debug("dsp = {}", new String(data));
        }
        Dsp dsp = JsonHelper.convert(data, Dsp.class);
        Long id = dsp.getId();
        updater.hremove(getKeyGenerator(), Objects.toString(id));
        if (!dsp.isForbidden()) {
            updater.hupdate(getKeyGenerator(), Objects.toString(id), dsp);
        }
        applicationContext.publishEvent(new DspChangedEvent(this, dsp));
    }

    private KeyGenerator getKeyGenerator() {
        return () -> KeyBuilder.build("ADX", "DSPS");
    }
}

==> adx-common-2.5.6.7-sources.jar: com/bxm/adx/common/buy/dsp/DspDaoImpl.java <==
package com.bxm.adx.common.buy.dsp;

import com.bxm.warcar.cache.Fetcher;
import com.bxm.warcar.cache.KeyGenerator;
import com.bxm.warcar.cache.Updater;
import com.bxm.warcar.cache.push.Pushable;
import com.bxm.warcar.integration.pushable.annotation.CachePush;
import com.bxm.warcar.utils.JsonHelper;
import com.bxm.warcar.utils.KeyBuilder;
import com.bxm.warcar.xcache.TargetFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeansException;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.stereotype.Component;

import java.util.Collection;
import java.util.Map;
import java.util.Objects;

/**
 * For cache pushable
 *
 * <pre>
 *     name = "DSP"
 *     parameters = {}
 *     byte[] = Dsp object to json bytes
 * </pre>
 *
 * @author allen
 * @since 2019-12-18
 */
@CachePush("DSP")
@Component
@Slf4j
public class DspDaoImpl implements DspDao, Pushable, ApplicationContextAware {

    private final Fetcher fetcher;
    private final Updater updater;
    private final com.bxm.warcar.xcache.Fetcher fetcher2;

    private ApplicationContext applicationContext;

    public DspDaoImpl(Fetcher fetcher, Updater updater, com.bxm.warcar.xcache.Fetcher fetcher2) {
        this.fetcher = fetcher;
        this.updater = updater;
        this.fetcher2 = fetcher2;
    }

    @Override
    public void setApplicationContext(ApplicationContext applicationContext) throws BeansException {
        this.applicationContext = applicationContext;
    }

    @Override
    public Collection<Dsp> getAll() {
//        return fetcher.hfetchall(getKeyGenerator(), Dsp.class).values();
        return fetcher2.hfetchall(
                new TargetFactory<Dsp>()
                        .expireTimeInSecond(600)
                        .cls(Dsp.class)
                        .skipNativeCache(false)
                        .keyGenerator(getKeyGenerator())
                        .build()
        ).values();
    }

    @Override
    public void push(Map<String, Object> parameters, byte[] data) {
        if (log.isDebugEnabled()) {
            log.debug("dsp = {}", new String(data));
        }
        Dsp dsp = JsonHelper.convert(data, Dsp.class);
        Long id = dsp.getId();
        updater.hremove(getKeyGenerator(), Objects.toString(id));
        if (!dsp.isForbidden()) {
            updater.hupdate(getKeyGenerator(), Objects.toString(id), dsp);
        }
        applicationContext.publishEvent(new DspChangedEvent(this, dsp));
    }

    private KeyGenerator getKeyGenerator() {
        return () -> KeyBuilder.build("ADX", "DSPS");
    }
}
